3.31.9 (2021-11-17)
===================
👷 Bug fixes
------------

- pkg: pin Yams version < 0.46.0

3.31.8 (2021-11-17)
===================
🤷 Various changes
------------------

- depend on sphinx >= 4.3

3.31.7 (2021-11-02)
===================
👷 Bug fixes
------------

- build_doc: docutils version 0.18.0 breaks doc building (`#443  <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/443>`_)
- pkg: don't use pyparsing 3 since it's not compatible with rdflib 5. (`#441 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/441>`_)
- pkg: pin pyramid_multiauth version to avoid compatibility issue with Pyramid 1 (`#450 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/450>`_)

3.31.6 (2021-09-28)
===================
🤷 Various changes
------------------

- backout "limit setuptools version to avoid issue with 2to3"
- use our package rdflib-jsonld-without-2to3, this is a fork of
  rdflib-jsonld with 2to3 usage removed, but which still
  contains the whole package code unlike rdflib-jsonld 0.6.x.

3.31.5 (2021-09-24)
===================
👷 Bug fixes
------------

- setup: keep rdflib-jsonld at version < 0.6.0
- setup: limit setuptools version to avoid issue with 2to3

3.31.4 (2021-09-14)
===================

- upgrade rdflib-jsonld version to keep compatibility with setupools
  58 and above

3.31.3 (2021-07-23)
===================
👷 Bug fixes
------------

- pin rdflib < 6.0.0 to avoid compatibility issues

🤖 Continuous integration
-------------------------

- use image from heptapod registry since r.intra was shut down

3.31.2 (2021-07-19)
===================

👷 Bug fixes
------------

- do not consume a lot of time to collect debug data if no one is listening on
  debug channels
- fix incomplete merge of previous versions (brings back ``write_front``)

3.31.1 (2021-05-18)
===================

Revert
------

- backed out changeset bcb633bd791d, don’t give event to notify_on_commit
  Notification are done using Operation, and Operation do not have a event
  attribute, because they can be used for several event.
  Moreover, this commit (bcb633bd791d) changed the prototype of the
  notify_on_commit without giving the right event to the Operation (which is a
  singleton).


3.31 (2021-05-04)
=================

🎉 New features
---------------

- handle same_site cookies configuration in pyramid.ini
- order: add support for order by NULLS LAST and NULLS FIRST
- improve default cubicweb skeleton

👷 Bug fixes
------------

- create anonymous user at runtime if it doesn't exist already.
- dbcreate: don't ask confirmation to create schema in automatic
- hooks/notification: BREAKING CHANGE correctly initialize operation with event attribute
- RQLExpression: performance issue on RQLExpressions using EXISTS()
  *BREAKING CHANGE*: explicitly use EXISTS in RQLExpression for permissions
- fix some security issues

Documentation
-------------

- tuto: add structure of "enhance views" museum tutorial part.
- tuto: redact "React in a CubicWeb view" museum tuto part.
- tuto: rename cubicweb-tuto to tuto, avoiding confusion with cubicweb_tuto

🤖 Continuous integration
-------------------------

- gitlab-ci: set expiration delay to 2 weeks for artifacts
- image is no longer a global keyword, use default
- rename jobs names to match global conventions
- test skeleton own tox in the CI

🤷 Various changes
------------------

- cleanup: Remove migrations for 3.21 and less
- py3: Rename ``raw_input`` (that does not exist anymore) to ``input``
- tests: create a .nobackup file in the data/database directory
  (`#298 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/298>`_)
